% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aux_organisecubefiles.R
\name{aux_organisecubefiles}
\alias{aux_organisecubefiles}
\title{Convert cube files to mseed or sac files and organise in directory structure.}
\usage{
aux_organisecubefiles(stationfile, input_dir, output_dir, format = "sac",
  channel_name = "bh", cpu, fringe = "constant", verbose = FALSE,
  gipptools)
}
\arguments{
\item{stationfile}{\code{Character} value, file name of the station info 
file, with extension. See \code{aux_stationinfofile}.}

\item{input_dir}{\code{Character} value, path to directory where all cube 
files to be processed as stored. Each set of files from one logger must be 
stored in a separate sub-directory named after the cube ID.}

\item{output_dir}{\code{Character} value, path to directory where output 
data is written to.}

\item{format}{\code{Character} value, output file format. One out of 
\code{"mseed"} and \code{"sac"}. Default is \code{"sac"}.}

\item{channel_name}{\code{Character} value, output file extension. One out 
of \code{"bh"} and \code{"p"}. Default is \code{"bh"}.}

\item{cpu}{\code{Numeric} value, fraction of CPUs to use for parallel 
processing. If omitted, one CPU is used.}

\item{fringe}{\code{Character} value, option to handle data outside the 
GPS-tagged time span. One out of \code{"skip"}, \code{"nominal"} or 
\code{"constant"}. Default is \code{"constant"}.}

\item{verbose}{\code{Logical} value, option to enable extended screen 
output of cubetools operations. Default is \code{FALSE}.}

\item{gipptools}{\code{Character} value, path to gipptools or cubetools 
directory.}
}
\value{
A set of hourly seismic files written to disk.
}
\description{
This function converts cube files to hourly mseed or sac files and 
organises these in a coherent directory structure, by year, Julian day, 
(station, hour and channel). It depends on the cubetools or gipptools  
software package (see details). The function is at an experimental stage  
and only used for data processing at the GFZ Geomorphology section, 
currently.
}
\details{
The function converts seismic data from the cube file format to either 
mseed (cf. \code{read_mseed}) or sac (cf. \code{read_sac}) and cuts the 
daily cube files to hourly files. These hourly files are organised in a 
coherent directory structure which is organised by year and Julian day. 
In each Julian day directory the hourly files are placed and named after 
the following scheme: STATIONID.YEAR.JULIANDAY.HOUR.MINUTE.SEC.CHANNEL.\cr
The function requires that the software cubetools 
(\code{http://www.omnirecs.de/documents.html}) or gipptools 
(\code{http://www.gfz-potsdam.de/en/section/geophysical-deep-sounding/infrastructure/geophysical-instrument-pool-potsdam-gipp/software/gipptools/}) 
are installed. \cr Specifying an input directory 
(\code{input_dir}) is mandatory. This input directory must only contain the 
subdirectories with the cube files to process, each set of cube files must 
be located in a separate subdirectory and these subdiretories must 
have the same name as specified by the logger IDs (\code{logger_ID}). An 
appropriate structure would be something like: \cr 
\enumerate{
  \item input
  \enumerate{
    \item A1A
      \enumerate{
        \item file1.A1A
        \item file2.A1A
      }
    \item A1B
      \enumerate{
        \item file1.A1B
        \item file2.A1B
      }
   }
}
}
\examples{

## uncomment to use

## basic example with minimum effort
# aux_organisecubefiles(stationfile = "output/stationinfo.txt", 
#                       input_dir = "input", 
#                       output_dir = "output", 
#                       gipptools = "software/gipptools-2015.225/")
                        
}
\author{
Michael Dietze
}
\keyword{eseis}
